@@ -2,7 +2,7 @@ from .freqnet import *
 from .model import *
 from .parts import *
 from .sample_rnn import *
-from .seq2seqlstm import *
+from .s2s_lstm import *
 from .wavenet import *
 
 __all__ = [_ for _ in dir() if not _.startswith("_")]
